@@ -86,6 +86,8 @@ struct c_block                     /* Elemental control block structure */
    int nsamplers;                  // number of sampler strings
    char *psamplers[MAX_SAMP];      // pointer to each sampler string (or NULL)
    char sampler_codes[256];        // contains all sampler strings
+   struct dstats sampler_delay[MAX_SAMP][2]; // additive delay per sampler (s), in sampler
+                                   // order, for each of 2 polarizations (L/R = X/Y)
    int interpolator;               // interpolation method
    int mbd_anchor;                 // mbd ambiguity choice: model or sbd
    struct dstats station_delay;    // station delay pc inject->digitizer (s)
