@@ -20,10 +20,8 @@
 #include <string.h>
 #include <complex.h>
 
-int
-precorrect (ovex, param, pass)
+int precorrect (ovex, pass)
 struct scan_struct *ovex;
-struct type_param *param;
 struct type_pass *pass;
     {
     int i, j, k, stn, n, fr, ntones, nin, mask, chind;
@@ -31,18 +29,19 @@ struct type_pass *pass;
            pcphas[2][2],            // indexed by [stn][pol]
            pcfreq[2];
     extern struct type_status status;
+    extern struct type_param param;
     extern int do_accounting;
     static double conrad = 0.01745329252;
 
                                     /* copy over ref. frequency */
-    param->ref_freq = (pass->control.ref_freq == NULLFLOAT)?
+    param.ref_freq = (pass->control.ref_freq == NULLFLOAT)?
                      pass->pass_data[0].frequency :
                      pass->control.ref_freq;
                                          
-    param->cor_limit = 16000.0;     /* Initialize large number threshold */
-    param->use_sample_cnts = pass->control.use_samples;
+    param.cor_limit = 16000.0;     /* Initialize large number threshold */
+    param.use_sample_cnts = pass->control.use_samples;
                                     // get interpolation method for this pass
-    param->interpol = pass->control.interpolator;
+    param.interpol = pass->control.interpolator;
                                     // calculate offsets of windows due to position offsets
                             
     // delay_offset = (pass->control.ra_offset  * rbase->t2600.u_obsfreq
@@ -54,42 +53,42 @@ struct type_pass *pass;
     delay_offset = 0.0;             // for now, just force 0 offset  rjc 99.8.13
     rate_offset = 0.0;
     
-    param->ion_pts = pass->control.ion_npts;
-    param->mbd_anchor = pass->control.mbd_anchor;
+    param.ion_pts = pass->control.ion_npts;
+    param.mbd_anchor = pass->control.mbd_anchor;
 
     for (i=0; i<2; i++)             // Copy windows into working area
         {
-        param->win_sb[i] = pass->control.sb_window[i] + delay_offset;
-        param->win_mb[i] = pass->control.mb_window[i] + delay_offset;
-        param->win_dr[i] = pass->control.dr_window[i] + rate_offset;
-        param->passband[i] = pass->control.passband[i];
+        param.win_sb[i] = pass->control.sb_window[i] + delay_offset;
+        param.win_mb[i] = pass->control.mb_window[i] + delay_offset;
+        param.win_dr[i] = pass->control.dr_window[i] + rate_offset;
+        param.passband[i] = pass->control.passband[i];
                                     // ionosphere window is about differential a priori
                                     // collapses if only 1 pt (i.e. no search)
-        param->win_ion[i] = (param->ion_pts > 1) ?
+        param.win_ion[i] = (param.ion_pts > 1) ?
             pass->control.ion_window[i] : 0.0;
-        param->win_ion[i] += (pass->control.ionosphere.rem == NULLFLOAT) ? 
+        param.win_ion[i] += (pass->control.ionosphere.rem == NULLFLOAT) ? 
                            0.0 : pass->control.ionosphere.rem;
-        param->win_ion[i] -= (pass->control.ionosphere.ref == NULLFLOAT) ? 
+        param.win_ion[i] -= (pass->control.ionosphere.ref == NULLFLOAT) ? 
                            0.0 : pass->control.ionosphere.ref;
         }
 
-    param->pc_mode[0] = pass->control.pc_mode.ref;
-    param->pc_mode[1] = pass->control.pc_mode.rem;
-    param->pc_period[0] = pass->control.pc_period.ref;
-    param->pc_period[1] = pass->control.pc_period.rem;
+    param.pc_mode[0] = pass->control.pc_mode.ref;
+    param.pc_mode[1] = pass->control.pc_mode.rem;
+    param.pc_period[0] = pass->control.pc_period.ref;
+    param.pc_period[1] = pass->control.pc_period.rem;
    
     status.lsb_phoff[0] = pass->control.lsb_offset.ref * conrad;
     status.lsb_phoff[1] = pass->control.lsb_offset.rem * conrad;
 
-    param->dc_block = pass->control.dc_block;
-    param->weak_channel = pass->control.weak_channel;
-    param->pc_amp_hcode = pass->control.pc_amp_hcode;
-    param->fmatch_bw_pct = pass->control.fmatch_bw_pct;
+    param.dc_block = pass->control.dc_block;
+    param.weak_channel = pass->control.weak_channel;
+    param.pc_amp_hcode = pass->control.pc_amp_hcode;
+    param.fmatch_bw_pct = pass->control.fmatch_bw_pct;
                                     // Copy phase cal offsets; identify desired pcal tone freqs
     for (stn=0; stn<2; stn++)
         {
-        n = param->ov_bline[stn];
-        param->pcal_spacing[stn] = ovex->st[n].channels[0].pcal_spacing;
+        n = param.ov_bline[stn];
+        param.pcal_spacing[stn] = ovex->st[n].channels[0].pcal_spacing;
         
         for (fr = 0; fr < pass->nfreq; fr++)  
             {
@@ -100,7 +99,7 @@ struct type_pass *pass;
             status.delay_offs[fr][stn] = (stn) ? pass->control.delay_offs[j].rem 
                                                : pass->control.delay_offs[j].ref;
 
-            if (param->pc_mode[stn] != MULTITONE)
+            if (param.pc_mode[stn] != MULTITONE)
                 {                   // single tone used in this frequency band, process it
                                     // find corresponding freq index in control structure
                 if (stn == 0)
@@ -168,7 +167,7 @@ struct type_pass *pass;
                     {
                     k = 0;
                     pcfreq_hz = pass->pass_data[fr].pc_freqs[stn][k];
-                    if (param->pc_mode[stn] != MANUAL)
+                    if (param.pc_mode[stn] != MANUAL)
                         msg ("stn %d pcal tone of %g Hz unavailable for channel %c",
                          1, stn, pcfreq_hz, pass->pass_data[fr].freq_code);
                     }
@@ -245,16 +244,16 @@ struct type_pass *pass;
         }                           // end of stn loop
 
                                     // copy in ad hoc phase model
-    param->ah_phase  = pass->control.adhoc_phase;
-    param->ah_tref   = pass->control.adhoc_tref;
-    param->ah_period = pass->control.adhoc_period;
-    param->ah_amp    = pass->control.adhoc_amp * conrad;
+    param.ah_phase  = pass->control.adhoc_phase;
+    param.ah_tref   = pass->control.adhoc_tref;
+    param.ah_period = pass->control.adhoc_period;
+    param.ah_amp    = pass->control.adhoc_amp * conrad;
     for (i=0; i<6; i++)
-        param->ah_poly[i] = pass->control.adhoc_poly[i] * conrad;
+        param.ah_poly[i] = pass->control.adhoc_poly[i] * conrad;
     for (i=0; i<2; i++)
         {
-        strcpy (param->ah_file[i], pass->control.adhoc_file[i]);
-        strcpy (param->ah_file_chans[i], pass->control.adhoc_file_chans[i]);
+        strcpy (param.ah_file[i], pass->control.adhoc_file[i]);
+        strcpy (param.ah_file_chans[i], pass->control.adhoc_file_chans[i]);
         }
 
     if (do_accounting) account ("PreCorrect data");
