@@ -99,7 +99,7 @@ int parse_station_name (char *in_line, int nbl, char *ref, char *rem);
 main(int argc, char *argv[])
 {
 
-  FILE *fp1,*fm, *fp2, *fp3, *fp, *fp_snr;
+  FILE *fm, *fp2, *fp3, *fp, *fp_snr;
 
   char bl[MAXBL][2],scantime[13],source[9],line[MAXLINLEN],ch,*st,snrp[5],freq;
   char bl1,bl2,dtime[11],qcode,qerr,lasttime[13],outname[12],teststring[6],bl_style;
@@ -117,13 +117,8 @@ main(int argc, char *argv[])
     exit(1);
   }
 
-//printf("fp1 = %s fp2 = %s fp3 = %s\n", argv[0], argv[1],argv[2] );
+//printf("fp2 = %s fp3 = %s\n", argv[1],argv[2] );
 
-  fp1 = fopen (argv[0], "r");
-  if (fp1 == NULL) {
-    printf("Trouble opening %s\n", argv[0]);
-    exit(1);
-  }
 
   fp2 = fopen (argv[1], "r"); 
   if (fp2 == NULL) {
@@ -190,8 +185,10 @@ main(int argc, char *argv[])
 /* open and read in memory file stations.m */
 
           if ((fm = fopen("stations.m","r")) == NULL) {
-            printf("......can't open stations.m file\n");
-            exit(2);
+            if ((fm = fopen("/correlator/data/expn/stations.m","r")) == NULL) {
+              printf("......can't find or open the stations.m file\n");
+              exit(2);
+            }
           }
           m = 0;
           while(fscanf(fm,"%2s %c\n",&stc[m], &st1c[m]) != EOF) {
